@@ -87,7 +87,7 @@ MARKER
   sed -i 's/nexus-webapp-context-path=.*/nexus-webapp-context-path=\//' /opt/nexus/current/conf/nexus.properties
 }
 install_nexus3() {
-  wget -O - https://sonatype-download.global.ssl.fastly.net/repository/repositoryManager/3/nexus-$NEXUS3_VERSION-unix.tar.gz | tar -xzf - -C /opt/nexus
+  wget -O - https://sonatype-download.global.ssl.fastly.net/repository/downloads-prod-group/3/nexus-$NEXUS3_VERSION-unix.tar.gz | tar -xzf - -C /opt/nexus
   chown -R nexus:nexus /opt/nexus
   ln -snf /opt/nexus/nexus-* /opt/nexus/current
   mv /opt/nexus/sonatype-work /opt/nexus/sonatype-work-initial
@@ -127,16 +127,6 @@ MARKER
   systemctl enable fail2ban
   systemctl start fail2ban
 }
-allow_authorizedkeyscommand() {
-  yum update -y selinux-policy*
-  local SOURCE=$(n-include ssh-authorized-keys-command.te)
-  local BASE=${SOURCE%.te}
-  local MODULE=$BASE.mod
-  local PACKAGE=$BASE.pp
-  checkmodule -M -m -o $MODULE $SOURCE
-  semodule_package -o $PACKAGE -m $MODULE
-  semodule -i $PACKAGE
-}
 update_deploytools() {
   if [ ! "$DEPLOYTOOLS_VERSION" ]; then
     echo "Specific version not defined - updating to latest"
@@ -152,14 +142,3 @@ update_aws_utils () {
   echo "Updating ndt as part of a bootup is no longer recommended"
   update_deploytools "$@"
 }
-
-install_nexus3_aptrepository() {
-  INST_DIR=/opt/nexus/current/system/net/staticsnow/nexus-repository-apt/$NEXUS_REPOSITORY_APT_VERSION/
-  mkdir -p $INST_DIR
-  FILE=nexus-repository-apt-$NEXUS_REPOSITORY_APT_VERSION.jar
-  wget -O $INST_DIR/$FILE https://github.com/freelancer/nexus-repository-apt/releases/download/$NEXUS_REPOSITORY_APT_VERSION/$FILE
-  chown -R nexus:nexus /opt/nexus/current/system/net/
-  FEATURES_FILE=/opt/nexus/current/system/org/sonatype/nexus/assemblies/nexus-core-feature/$NEXUS3_VERSION/nexus-core-feature-$NEXUS3_VERSION-features.xml
-  sed -i '/>nexus-repository-maven/a \ \ \ \ \ \ \ \ <feature prerequisite="false" dependency="false">nexus-repository-apt</feature>' "$FEATURES_FILE"
-  sed -i "/feature name=\"nexus-repository-maven\"/i  <feature name=\"nexus-repository-apt\" description=\"net.staticsnow:nexus-repository-apt\" version=\"$NEXUS_REPOSITORY_APT_VERSION\">\n  <details>net.staticsnow:nexus-repository-apt</details>\n  <bundle>mvn:net.staticsnow/nexus-repository-apt/$NEXUS_REPOSITORY_APT_VERSION</bundle>\n  <bundle>mvn:org.tukaani/xz/1.8</bundle>\n</feature>\n" "$FEATURES_FILE"
-}
